==> cloudfront-1.60.0-sources.jar: software/amazon/awscdk/services/cloudfront/OriginBindOptions.java <==
package software.amazon.awscdk.services.cloudfront;

/**
 * Options passed to Origin.bind().
 * <p>
 * EXPERIMENTAL
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.9.0 (build 5c646d5)", date = "2020-08-19T23:25:15.535Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.cloudfront.$Module.class, fqn = "@aws-cdk/aws-cloudfront.OriginBindOptions")
@software.amazon.jsii.Jsii.Proxy(OriginBindOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface OriginBindOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * The identifier of this Origin, as assigned by the Distribution this Origin has been used added to.
     * <p>
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull java.lang.String getOriginId();

    /**
     * @return a {@link Builder} of {@link OriginBindOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link OriginBindOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<OriginBindOptions> {
        private java.lang.String originId;

        /**
         * Sets the value of {@link OriginBindOptions#getOriginId}
         * @param originId The identifier of this Origin, as assigned by the Distribution this Origin has been used added to. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder originId(java.lang.String originId) {
            this.originId = originId;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link OriginBindOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public OriginBindOptions build() {
            return new Jsii$Proxy(originId);
        }
    }

    /**
     * An implementation for {@link OriginBindOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements OriginBindOptions {
        private final java.lang.String originId;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.originId = this.jsiiGet("originId", java.lang.String.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final java.lang.String originId) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.originId = java.util.Objects.requireNonNull(originId, "originId is required");
        }

        @Override
        public java.lang.String getOriginId() {
            return this.originId;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("originId", om.valueToTree(this.getOriginId()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-cloudfront.OriginBindOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            OriginBindOptions.Jsii$Proxy that = (OriginBindOptions.Jsii$Proxy) o;

            return this.originId.equals(that.originId);
        }

        @Override
        public int hashCode() {
            int result = this.originId.hashCode();
            return result;
        }
    }
}

==> cloudfront-1.93.0-sources.jar: software/amazon/awscdk/services/cloudfront/OriginBindOptions.java <==
package software.amazon.awscdk.services.cloudfront;

/**
 * Options passed to Origin.bind().
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.24.0 (build b722f66)", date = "2021-03-11T13:46:52.430Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.cloudfront.$Module.class, fqn = "@aws-cdk/aws-cloudfront.OriginBindOptions")
@software.amazon.jsii.Jsii.Proxy(OriginBindOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface OriginBindOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * The identifier of this Origin, as assigned by the Distribution this Origin has been used added to.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getOriginId();

    /**
     * @return a {@link Builder} of {@link OriginBindOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link OriginBindOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<OriginBindOptions> {
        private java.lang.String originId;

        /**
         * Sets the value of {@link OriginBindOptions#getOriginId}
         * @param originId The identifier of this Origin, as assigned by the Distribution this Origin has been used added to. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder originId(java.lang.String originId) {
            this.originId = originId;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link OriginBindOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public OriginBindOptions build() {
            return new Jsii$Proxy(originId);
        }
    }

    /**
     * An implementation for {@link OriginBindOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements OriginBindOptions {
        private final java.lang.String originId;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.originId = software.amazon.jsii.Kernel.get(this, "originId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final java.lang.String originId) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.originId = java.util.Objects.requireNonNull(originId, "originId is required");
        }

        @Override
        public final java.lang.String getOriginId() {
            return this.originId;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("originId", om.valueToTree(this.getOriginId()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-cloudfront.OriginBindOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            OriginBindOptions.Jsii$Proxy that = (OriginBindOptions.Jsii$Proxy) o;

            return this.originId.equals(that.originId);
        }

        @Override
        public final int hashCode() {
            int result = this.originId.hashCode();
            return result;
        }
    }
}
